@@ -11,16 +11,16 @@ if __name__ == "__main__":
     # """
     darthvader = Abraham(
         news_source="newsapi",
-        newsapi_key=open("keys/newsapi-public").read().strip(),
-        # bearer_token=open("keys/twitter-bearer-token").read().strip(),
+        newsapi_key=open("keys/newsapi-public-2").read().strip(),
+        tqdisable=False,
+        bearer_token=open("keys/twitter-bearer-token").read().strip(),
     )  # splitting means that it recursively splits a large text into sentences and analyzes each individually
 
-    scores = darthvader.twitter_summary(
-        *args,  # size=200
-    )  # latest date to get news from
-    print("\nTwitter\n--")
-    pprint(scores)
-
     scores = darthvader.news_summary(*args)  # latest date to get news from
     print("News\n--")
+    pprint(scores)
+    scores = darthvader.twitter_summary_interval(
+        *args,  # size=200
+    )  # latest date to get news from
+    print("\nTwitter\n--")
     pprint(scores)
\ No newline at end of file
